@@ -1,4 +1,4 @@
-package Pcore::PDF v0.5.2;
+package Pcore::PDF v0.5.3;
 
 use Pcore -dist, -class, -const, -res;
 use Config;
@@ -302,22 +302,22 @@ Pcore::PDF - non-blocking HTML to PDF converter
         max_threads => 4,
     });
 
-    my $cv = AE::cv;
+    # blocking mode, blocks only current coroutine
+    my $res = $pdf->generate_pdf($html);
 
+    # non-blocking mode
     $pdf->generate_pdf($html, sub ($res) {
         if (!$res) {
             say $res;
         }
         else {
 
-            # $res->{data}->{pdf} contains ScalarRef to generated PDF content
+            # $res->{data} contains ScalarRef to generated PDF content
         }
 
         return;
     });
 
-    $cv->recv;
-
 =head1 DESCRIPTION
 
 Generate PDF from HTML templates, using princexml.
@@ -332,7 +332,7 @@ Path to F<princexml> executable. Mandatory attribute.
 
 =item max_threads
 
-Maximum number of princexml processes. Under Windows this value is always C<< 1 >>, under linux default value is C<< 4 >>.
+Maximum number of princexml processes. Default value is C<< 4 >>.
 
 =back
 
@@ -340,9 +340,9 @@ Maximum number of princexml processes. Under Windows this value is always C<< 1
 
 =over
 
-=item generate_pdf( $self, $html, $cb )
+=item generate_pdf( $self, $html, $cb = undef )
 
-Generates PDF from C<< $html >> template. Call C<< $cb->($result) >> on finish, where C<< $result >> is a standard Pcore API result object, see L<Pcore::Util::Result> documentation for details.
+Generates PDF from C<< $html >> template. C<< $result >> is a standard Pcore API result object, see L<Pcore::Util::Result> documentation for details.
 
 =back
 
